from django.core.management.base import BaseCommand, CommandError
from django.utils.crypto import get_random_string


class Command(BaseCommand):
	help = 'Generate a new Django secret key'

	def handle(self, *args, **options):
		characters = 'abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'
		key = get_random_string(50, characters)
		self.stdout.write(self.style.SUCCESS(key))


from setuptools import find_packages, setup

setup(
	name='django-key-generator',
	version='1.0.3',
	description='A django-admin command to generate a secret key',
	url='https://github.com/TrianglePlusPlus/django-key-generator',
	author='Triangle++',
	author_email='justice.suh@gmail.com',
	license='MIT',
	packages=find_packages(),
	install_requires=['django']
	)